summaryrefslogtreecommitdiff
path: root/src/bignum.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/bignum.c')
-rw-r--r--src/bignum.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/bignum.c b/src/bignum.c
index 35894f5647d..f4c24d132be 100644
--- a/src/bignum.c
+++ b/src/bignum.c
@@ -64,9 +64,9 @@ bignum_to_double (Lisp_Object n)
return mpz_get_d (XBIGNUM (n)->value);
}
/* Return D, converted to a bignum. Discard any fraction. */
Lisp_Object
-double_to_bignum (double d)
+double_to_integer (double d)
{
mpz_set_d (mpz[0], d);
return make_integer_mpz ();
@@ -64,9 +64,9 @@ bignum_to_double (Lisp_Object n)
return mpz_get_d (XBIGNUM (n)->value);
}
-/* Return D, converted to a bignum. Discard any fraction. */
+/* Return D, converted to a Lisp integer. Discard any fraction. */
Lisp_Object